/********************************************************************************
** Form generated from reading UI file 'cfg_advanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CFG_ADVANCED_H
#define UI_CFG_ADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigAdvanced
{
public:
    QFormLayout *formLayout;
    QCheckBox *kcfg_AlwaysOnTop;

    void setupUi(QWidget *ConfigAdvanced)
    {
        if (ConfigAdvanced->objectName().isEmpty())
            ConfigAdvanced->setObjectName("ConfigAdvanced");
        ConfigAdvanced->resize(400, 300);
        formLayout = new QFormLayout(ConfigAdvanced);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        kcfg_AlwaysOnTop = new QCheckBox(ConfigAdvanced);
        kcfg_AlwaysOnTop->setObjectName("kcfg_AlwaysOnTop");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_AlwaysOnTop);


        retranslateUi(ConfigAdvanced);

        QMetaObject::connectSlotsByName(ConfigAdvanced);
    } // setupUi

    void retranslateUi(QWidget *ConfigAdvanced)
    {
#if QT_CONFIG(tooltip)
        kcfg_AlwaysOnTop->setToolTip(tr2i18n("If this option is enabled, the window is being kept above other windows.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AlwaysOnTop->setText(tr2i18n("Always on top", nullptr));
        (void)ConfigAdvanced;
    } // retranslateUi

};

namespace Ui {
    class ConfigAdvanced: public Ui_ConfigAdvanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CFG_ADVANCED_H

