/********************************************************************************
** Form generated from reading UI file 'cfg_appearance.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CFG_APPEARANCE_H
#define UI_CFG_APPEARANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigAppearance
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KColorButton *kcfg_BgColor;
    QLabel *label_2;
    KFontRequester *kcfg_ScaleFont;
    QCheckBox *kcfg_TrayIcon;

    void setupUi(QWidget *ConfigAppearance)
    {
        if (ConfigAppearance->objectName().isEmpty())
            ConfigAppearance->setObjectName("ConfigAppearance");
        ConfigAppearance->resize(400, 300);
        formLayout = new QFormLayout(ConfigAppearance);
        formLayout->setObjectName("formLayout");
        label = new QLabel(ConfigAppearance);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        kcfg_BgColor = new KColorButton(ConfigAppearance);
        kcfg_BgColor->setObjectName("kcfg_BgColor");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_BgColor);

        label_2 = new QLabel(ConfigAppearance);
        label_2->setObjectName("label_2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_ScaleFont = new KFontRequester(ConfigAppearance);
        kcfg_ScaleFont->setObjectName("kcfg_ScaleFont");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ScaleFont);

        kcfg_TrayIcon = new QCheckBox(ConfigAppearance);
        kcfg_TrayIcon->setObjectName("kcfg_TrayIcon");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_TrayIcon);


        retranslateUi(ConfigAppearance);

        QMetaObject::connectSlotsByName(ConfigAppearance);
    } // setupUi

    void retranslateUi(QWidget *ConfigAppearance)
    {
        label->setText(tr2i18n("Background color:", nullptr));
        label_2->setText(tr2i18n("Font:", nullptr));
        kcfg_TrayIcon->setText(tr2i18n("Show tray icon", nullptr));
        (void)ConfigAppearance;
    } // retranslateUi

};

namespace Ui {
    class ConfigAppearance: public Ui_ConfigAppearance {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CFG_APPEARANCE_H

